#!/usr/bin/env python
exec(open('report.py', 'r').read())
fig.savefig('result.png')
